@@ -52,8 +52,8 @@ public:
     void clear();
 
 protected:
-    uint       rType;
-    uint       quantity;
+    uint rType;
+    uint quantity;
     QByteArray key;
     QByteArray val;
     QByteArray extra;
@@ -61,7 +61,6 @@ protected:
 
 class kio_sieveProtocol : public KIO::TCPSlaveBase
 {
-
 public:
     enum connectionModes {
         NORMAL,
@@ -75,20 +74,20 @@ public:
     };
 
     kio_sieveProtocol(const QByteArray &pool_socket, const QByteArray &app_socket);
-    virtual ~kio_sieveProtocol();
+    ~kio_sieveProtocol() override;
 
-    void mimetype(const QUrl &url) Q_DECL_OVERRIDE;
-    void get(const QUrl &url) Q_DECL_OVERRIDE;
-    void put(const QUrl &url, int permissions, KIO::JobFlags flags) Q_DECL_OVERRIDE;
-    void del(const QUrl &url, bool isfile) Q_DECL_OVERRIDE;
+    void mimetype(const QUrl &url) override;
+    void get(const QUrl &url) override;
+    void put(const QUrl &url, int permissions, KIO::JobFlags flags) override;
+    void del(const QUrl &url, bool isfile) override;
 
-    void listDir(const QUrl &url) Q_DECL_OVERRIDE;
-    void chmod(const QUrl &url, int permissions) Q_DECL_OVERRIDE;
+    void listDir(const QUrl &url) override;
+    void chmod(const QUrl &url, int permissions) override;
     virtual void urlStat(const QUrl &url);
 
-    void setHost(const QString &host, quint16 port, const QString &user, const QString &pass) Q_DECL_OVERRIDE;
-    void openConnection() Q_DECL_OVERRIDE;
-    void closeConnection() Q_DECL_OVERRIDE;
+    void setHost(const QString &host, quint16 port, const QString &user, const QString &pass) override;
+    void openConnection() override;
+    void closeConnection() override;
     //virtual void slave_status();
 
     /**
@@ -97,7 +96,7 @@ public:
      * 2 - deactivate (all - only one active at any one time) scripts
      * 3 - request capabilities, returned as metadata
      */
-    void special(const QByteArray &data) Q_DECL_OVERRIDE;
+    void special(const QByteArray &data) override;
     bool activate(const QUrl &url);
     bool deactivate();
 
@@ -116,23 +115,23 @@ protected:
     bool saslInteract(void *in, KIO::AuthInfo &ai);
 
     // IOSlave global data
-    uint              m_connMode;
+    uint m_connMode;
 
     // Host-specific data
-    QStringList       m_sasl_caps;
-    bool              m_supportsTLS;
+    QStringList m_sasl_caps;
+    bool m_supportsTLS;
 
     // Global server respose class
     kio_sieveResponse r;
 
     // connection details
-    QString           m_sServer;
-    QString           m_sUser;
-    QString           m_sPass;
-    QString           m_sAuth;
-    bool              m_shouldBeConnected;
-    bool              m_allowUnencrypted;
-    quint16           m_port;
+    QString m_sServer;
+    QString m_sUser;
+    QString m_sPass;
+    QString m_sAuth;
+    bool m_shouldBeConnected;
+    bool m_allowUnencrypted;
+    quint16 m_port;
 
 private:
     bool requestCapabilitiesAfterStartTLS() const;
