@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,11 +19,11 @@
 #ifndef SELECTMATCHTYPECOMBOBOX_H
 #define SELECTMATCHTYPECOMBOBOX_H
 
-#include <KComboBox>
+#include <QComboBox>
 
 namespace KSieveUi {
 class SieveEditorGraphicalModeWidget;
-class SelectMatchTypeComboBox : public KComboBox
+class SelectMatchTypeComboBox : public QComboBox
 {
     Q_OBJECT
 public:
@@ -42,7 +42,7 @@ Q_SIGNALS:
 private:
     void slotValueChanged(int val);
     void initialize();
-    bool mHasRegexCapability;
+    bool mHasRegexCapability = false;
 };
 }
 
