@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,8 +34,8 @@ public:
     QUrl href() const override;
 
 private:
-    bool mHasFlagSupport;
-    bool mHasImapFlag4Support;
+    bool mHasFlagSupport = false;
+    bool mHasImapFlag4Support = false;
 };
 }
 #endif // SIEVEACTIONKEEP_H
