@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,12 +21,15 @@
 
 #include <QLineEdit>
 #include <KLocalizedString>
+#include <KConfigGroup>
+#include <KSharedConfig>
 
 #include <QPushButton>
 #include <QHBoxLayout>
 #include <QPointer>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
+#include <QToolButton>
 
 using namespace KSieveUi;
 
@@ -35,10 +38,10 @@ SelectFlagsListDialog::SelectFlagsListDialog(QWidget *parent)
 {
     setWindowTitle(i18n("Flags"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mListWidget = new SelectFlagsListWidget(this);
     mainLayout->addWidget(mListWidget);
 
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -46,10 +49,27 @@ SelectFlagsListDialog::SelectFlagsListDialog(QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SelectFlagsListDialog::reject);
     mainLayout->addWidget(buttonBox);
     okButton->setFocus();
+    readConfig();
 }
 
 SelectFlagsListDialog::~SelectFlagsListDialog()
 {
+    writeConfig();
+}
+
+void SelectFlagsListDialog::readConfig()
+{
+    KConfigGroup group(KSharedConfig::openConfig(), "SelectFlagsListDialog");
+    const QSize sizeDialog = group.readEntry("Size", QSize(300, 200));
+    if (sizeDialog.isValid()) {
+        resize(sizeDialog);
+    }
+}
+
+void SelectFlagsListDialog::writeConfig()
+{
+    KConfigGroup group(KSharedConfig::openConfig(), "SelectFlagsListDialog");
+    group.writeEntry("Size", size());
 }
 
 void SelectFlagsListDialog::setFlags(const QStringList &list)
@@ -120,16 +140,18 @@ QStringList SelectFlagsListWidget::flags() const
 SelectFlagsWidget::SelectFlagsWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *lay = new QHBoxLayout;
+    QHBoxLayout *lay = new QHBoxLayout(this);
     lay->setMargin(0);
-    mEdit = new QLineEdit;
+    mEdit = new QLineEdit(this);
     mEdit->setReadOnly(true);
+    mEdit->setPlaceholderText(i18n("Click on button for selecting flags..."));
     connect(mEdit, &QLineEdit::textChanged, this, &SelectFlagsWidget::valueChanged);
     lay->addWidget(mEdit);
-    QPushButton *selectFlags = new QPushButton(i18n("..."));
+    QToolButton *selectFlags = new QToolButton(this);
+    selectFlags->setText(i18n("..."));
+    selectFlags->setToolTip(i18n("Select Flags"));
     connect(selectFlags, &QPushButton::clicked, this, &SelectFlagsWidget::slotSelectFlags);
     lay->addWidget(selectFlags);
-    setLayout(lay);
 }
 
 SelectFlagsWidget::~SelectFlagsWidget()
@@ -147,7 +169,6 @@ void SelectFlagsWidget::slotSelectFlags()
             flags = AutoCreateScriptUtil::createList(lstFlags);
         }
         mEdit->setText(flags);
-
     }
     delete dialog;
 }
@@ -161,4 +182,3 @@ QString SelectFlagsWidget::code() const
 {
     return mEdit->text();
 }
-
