@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -55,16 +55,14 @@ public:
     QString headers() const;
     void setListHeaders(const QMap<QString, QString> &lst, const QStringList &selectedHeaders);
 
-private Q_SLOTS:
+private:
     void slotNewHeaderTextChanged(const QString &text);
     void slotAddNewHeader();
-
-private:
     void readConfig();
     void writeConfig();
-    SelectHeadersWidget *mListWidget;
-    KLineEdit *mNewHeader;
-    QPushButton *mAddNewHeader;
+    SelectHeadersWidget *mListWidget = nullptr;
+    KLineEdit *mNewHeader = nullptr;
+    QPushButton *mAddNewHeader = nullptr;
 };
 
 class SelectHeaderTypeComboBox : public QComboBox
