@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -154,7 +154,17 @@ void SieveEditorGraphicalModeWidget::setImportScript(const QString &script)
     }
 }
 
+void SieveEditorGraphicalModeWidget::setListOfIncludeFile(const QStringList &listOfIncludeFile)
+{
+    mListOfIncludeFile = listOfIncludeFile;
+}
+
 void SieveEditorGraphicalModeWidget::slotSwitchToTextMode()
 {
-    switchTextMode(mSieveParsingWarning->initialScript());
+    Q_EMIT switchTextMode(mSieveParsingWarning->initialScript());
+}
+
+QStringList KSieveUi::SieveEditorGraphicalModeWidget::listOfIncludeFile() const
+{
+    return mListOfIncludeFile;
 }
