@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,7 +23,8 @@
 #include "sieveforeverypartwidget.h"
 #include "sievescriptpage.h"
 #include "sieveincludewidget.h"
-
+#include "sieveeditorgraphicalmodewidget.h"
+#include <QXmlStreamReader>
 #include <QHBoxLayout>
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -31,12 +32,10 @@
 #include <QPushButton>
 #include <KIconLoader>
 #include <QIcon>
-#include <QXmlStreamWriter>
 
 #include <QVBoxLayout>
 #include <QListWidget>
 #include <QPointer>
-#include <QDomElement>
 #include "libksieve_debug.h"
 
 namespace {
@@ -82,8 +81,8 @@ QString SieveScriptListItem::generatedScript(QStringList &requires) const
 {
     QString script;
     if (!mDescription.trimmed().isEmpty()) {
-        const QStringList commentList = mDescription.split(QLatin1Char('\n'));
-        for (const QString &str : commentList) {
+        const QVector<QStringRef> commentList = mDescription.splitRef(QLatin1Char('\n'));
+        for (const QStringRef &str : commentList) {
             if (str.isEmpty()) {
                 script += QLatin1Char('\n');
             } else {
@@ -99,8 +98,6 @@ QString SieveScriptListItem::generatedScript(QStringList &requires) const
 
 SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     : QGroupBox(title, parent)
-    , mSieveGraphicalModeWidget(nullptr)
-    , mScriptNumber(0)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
     mSieveListScript = new QListWidget(this);
@@ -235,6 +232,7 @@ SieveScriptPage *SieveScriptListBox::createNewScript(const QString &newName, con
     SieveScriptListItem *item = new SieveScriptListItem(newName, mSieveListScript);
     item->setDescription(description);
     SieveScriptPage *page = new SieveScriptPage(mSieveGraphicalModeWidget);
+    page->setListOfIncludeFile(mSieveGraphicalModeWidget->listOfIncludeFile());
     item->setScriptPage(page);
     Q_EMIT addNewPage(page);
     Q_EMIT enableButtonOk(true);
@@ -416,8 +414,8 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
             if (typeBlock == TypeBlockAction) {
                 currentPage = nullptr;
             }
-            if (n.attributes().hasAttribute(QStringLiteral("name"))) {
-                const QString controlType = n.attributes().value(QStringLiteral("name")).toString();
+            if (n.attributes().hasAttribute(QLatin1String("name"))) {
+                const QString controlType = n.attributes().value(QLatin1String("name")).toString();
                 //qCDebug(LIBKSIEVE_LOG)<<" controlType"<<controlType;
                 if (controlType == QLatin1String("if")) {
                     typeBlock = TypeBlockIf;
@@ -474,7 +472,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
             }
         } else if (tagName == QLatin1String("comment")) {
             previousElementWasAComment = true;
-#ifdef QDOMELEMENT_FIXME
+#ifdef FIXME_COMMENT
             if (e.hasAttribute(QStringLiteral("hash"))) {
                 //TODO
             } else if (e.hasAttribute(QStringLiteral("bracket"))) {
@@ -493,8 +491,8 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
             //qDebug() << " COMMENT " << comment;
         } else if (tagName == QLatin1String("action")) {
             previousElementWasAComment = false;
-            if (n.attributes().hasAttribute(QStringLiteral("name"))) {
-                const QString actionName = n.attributes().value(QStringLiteral("name")).toString();
+            if (n.attributes().hasAttribute(QLatin1String("name"))) {
+                const QString actionName = n.attributes().value(QLatin1String("name")).toString();
                 if (actionName == QLatin1String("include")) {
                     if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
                         currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
@@ -523,7 +521,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                         const SieveGlobalVariableActionWidget::VariableElement var = currentPage->globalVariableWidget()->loadSetVariable(n, error);
                         if (var.isValid()) {
                             qCDebug(LIBKSIEVE_LOG) << "It's not a global variable";
-                            if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
+                            if ((typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
                                 currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
                             }
                             typeBlock = TypeBlockAction;
