@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,8 +29,6 @@ using KSieve::Parser;
 #include <ksieve/scriptbuilder.h>
 #include <QFileDialog>
 #include <QApplication>
-#include <KAboutData>
-#include <KLocalizedString>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 
@@ -41,25 +39,20 @@ using KSieve::Parser;
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("parsingscript_gui"), i18n("ParsingScriptTest_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for parsing script dialog"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"), i18n("URL of a sieve script to be opened")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"), QStringLiteral("URL of a sieve script to be opened")));
 
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     QByteArray script;
 
     QString fileName;
-    if (parser.positionalArguments().count()) {
+    if (!parser.positionalArguments().isEmpty()) {
         fileName = parser.positionalArguments().at(0);
     } else {
-        fileName = QFileDialog::getOpenFileName(nullptr, QString(), QString(), i18n("Sieve File (*.siv)"));
+        fileName = QFileDialog::getOpenFileName(nullptr, QString(), QString(), QStringLiteral("Sieve File (*.siv)"));
     }
     if (!fileName.isEmpty()) {
         QFile file(fileName);
@@ -71,8 +64,8 @@ int main(int argc, char **argv)
     }
     //qDebug() << "scriptUtf8 = \"" + script +"\"";
 
-    KSieve::Parser sieveParser(script.begin(),
-                               script.begin() + script.length());
+    KSieve::Parser sieveParser(script.constBegin(),
+                               script.constBegin() + script.length());
     KSieveUi::XMLPrintingScriptBuilder psb(2);
     sieveParser.setScriptBuilder(&psb);
     if (sieveParser.parse()) {
