@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,7 +29,7 @@ class KSIEVEUI_EXPORT SieveEditorTabWidget : public QTabWidget
     Q_OBJECT
 public:
     explicit SieveEditorTabWidget(QWidget *parent = nullptr);
-    ~SieveEditorTabWidget();
+    ~SieveEditorTabWidget() override;
 
     QUrl currentHelpUrl() const;
     QString currentHelpTitle() const;
