@@ -1,4 +1,4 @@
-/* Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -43,7 +43,7 @@ class KSIEVEUI_EXPORT SieveEditorTextModeWidget : public SieveEditorAbstractWidg
     Q_OBJECT
 public:
     explicit SieveEditorTextModeWidget(QWidget *parent = nullptr);
-    ~SieveEditorTextModeWidget();
+    ~SieveEditorTextModeWidget() override;
 
     void setSieveCapabilities(const QStringList &capabilities);
     void setReadOnly(bool b);
