@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,9 +23,9 @@
 #include <QDialog>
 #include <QUrl>
 #include "ksieveui_export.h"
+#include "util_p.h"
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class VacationCreateScriptJob;
 class MultiImapVacationManager;
 class MultiImapVacationDialogPrivate;
@@ -33,7 +33,7 @@ class KSIEVEUI_EXPORT MultiImapVacationDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit MultiImapVacationDialog(MultiImapVacationManager *manager, QWidget *parent = Q_NULLPTR);
+    explicit MultiImapVacationDialog(MultiImapVacationManager *manager, QWidget *parent = nullptr);
     ~MultiImapVacationDialog();
 
     QList<VacationCreateScriptJob *> listCreateJob() const;
@@ -48,7 +48,7 @@ private:
     void slotOkClicked();
     void slotDefaultClicked();
     void slotCanceled();
-    void createPage(const QString &serverName, const QUrl &url);
+    void createPage(const QString &serverName, const KSieveUi::Util::AccountInfo &info);
     void init();
     void readConfig();
     void writeConfig();
