@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
 
 #include <QWidget>
 #include "ksieveui_export.h"
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveImapAccountSettings;
 class KSIEVEUI_EXPORT AbstractMoveImapFolderWidget : public QWidget
 {
