@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,13 +27,13 @@ class CustomManageSieveWidget : public KSieveUi::ManageSieveWidget
     Q_OBJECT
 public:
     explicit CustomManageSieveWidget(SieveImapPasswordProvider *passwordProvider, QWidget *parent = nullptr);
-    virtual ~CustomManageSieveWidget();
+    ~CustomManageSieveWidget() override;
 
 protected:
     bool refreshList() override;
 
 private:
-    SieveImapPasswordProvider *mPasswordProvider;
+    SieveImapPasswordProvider *mPasswordProvider = nullptr;
 };
 }
 
